Sample data.table containing enrichment results (over-representation, ORA) from different databases, which are:
Disease Ontology
Gene Ontology (GO), Biological Process (BP)
Gene Ontology (GO), Molecular Function (MF)
Gene Ontology (GO), Cellular Component(CC)
Kyoto Encyclopedia of Genes and Genomes
KEGG Modules
Reactome
1 |
data.table columns for each item in the list contain:
Comparison made by differential expression analysis (e.g. AvsB: Group A vs. Group B)
Enriched term with up-regulated (up), down-regulated (down) or both up/down-regulated (all) genes
Enrichment methods. ORA: Over-representation analysis
Ontology database
ID of the enrichment term in the ontology database
Description of the enriched term
Gene Ratio. See clusterProfiler package for details
Background Ratio. See clusterProfiler package for details
p-value
p-values adjusted for multiple testing using "BH" method. See p.adjust for details.
p-values adjusted for multiple testing using "qvalue" method. See qvalue package for details.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.